from setuptools import setup

setup(
    name='RPICommLink',
    version='1.0.4',
    author='adixu',
    author_email='adixu7@gmail.com',
    description='A library for communication on Raspberry Pi',
    long_description="RPICommLink 是一个用于在不同设备之间建立通信连接的 Python 类。提供了一系列方法使设备能够通过 TCP/IP 协议进行数据交换。"
                     "灵活的通信设置可以轻松地在设备之间建立通信连接，无论是在局域网内部还是通过互联网。"
                     "具备完善的错误处理机制及时发现并处理连接中断、超时等异常情况，保证通信的稳定性和可靠性。"
                     "使用简单易用的接口可以方便地发送和接收数据，无需过多关注底层网络细节，让设备之间的通信变得更加简单和高效。"
                     "通过 RPICommLink 类，可以实现设备之间的数据交换，为项目提供强大的通信支持。"
                     "\n\n\n\n\n\n历代版本更新："
                     "\n\n\n\n\n\n1.0.2 -优化了函数的命名，发送模块不再进行死循环。"
                     "\n\n\n\n\n\n1.0.3 -修复了潜在bug，优化了获取IP的方式，现在可以不命名而使用默认设备名称了。添加了中文介绍。"
                     "\n\n\n\n\n\n1.0.4 -重新了上传中文介绍",
    packages=['RPICommLink'],
    install_requires=[],
)
